# installation

```
pip install lazyerrors
```

# usage

```
>> from lazyerrors import LazinessError
>> raise LazinessError("Please fix this bug", "tired@grad.school.edu")
```

# todo

[ ] fill in readme

